==> jc-unilever-client-0.1.412-sources.jar: com/xforceplus/ultraman/app/jcunilever/controller/OrderPoolFeignApi.java <==
package com.xforceplus.ultraman.app.jcunilever.controller;


/**
 * 订单池feign客户端
 *
 * @author ultraman
 * @date 2023-06-07
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.jcunilever.entity.OrderPool;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-unilever")
public interface OrderPoolFeignApi {

  /**
   * 通过id查询订单池
   * @param  id
   * @return R
   */
  @GetMapping("/orderPool/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增订单池
   * @param orderPool 订单池
   * @return R
   */
  @PostMapping("/orderPool/add")
  public R save(@RequestBody OrderPool orderPool);

  /**
   * 修改订单池
   * @param orderPool 订单池
   * @return R
   */
  @PostMapping("/orderPool/update")
  public R updateById(@RequestBody OrderPool orderPool);

  /**
   * 通过id删除订单池
   * @param  id
   * @return R
   */
  @DeleteMapping("/orderPool/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-unilever-client-0.1.669-sources.jar: com/xforceplus/ultraman/app/jcunilever/controller/OrderPoolFeignApi.java <==
package com.xforceplus.ultraman.app.jcunilever.controller;


/**
 * DTC业务feign客户端
 *
 * @author ultraman
 * @date 2023-11-29
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.jcunilever.entity.OrderPool;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-unilever")
public interface OrderPoolFeignApi {

  /**
   * 通过id查询DTC业务
   * @param  id
   * @return R
   */
  @GetMapping("/orderPool/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增DTC业务
   * @param orderPool DTC业务
   * @return R
   */
  @PostMapping("/orderPool/add")
  public R save(@RequestBody OrderPool orderPool);

  /**
   * 修改DTC业务
   * @param orderPool DTC业务
   * @return R
   */
  @PostMapping("/orderPool/update")
  public R updateById(@RequestBody OrderPool orderPool);

  /**
   * 通过id删除DTC业务
   * @param  id
   * @return R
   */
  @DeleteMapping("/orderPool/del/{id}" )
  public R removeById(@PathVariable Long id);

}
